@@ -1,7 +1,8 @@
 from cms.plugin_pool import plugin_pool
+from django.apps import apps
 from django.utils.translation import gettext_lazy as _
 
-from djangocms_frontend.helpers import get_plugin_template
+from djangocms_frontend.helpers import get_plugin_template, insert_fields
 
 from ... import settings
 from ...cms_plugins import CMSUIPlugin
@@ -16,7 +17,9 @@ mixin_factory = settings.get_renderer(link)
 
 UILINK_FIELDS = (
     ("name", "link_type"),
-    ("external_link", "internal_link"),
+    ("site", "url_grouper")
+    if apps.is_installed("djangocms_url_manager")
+    else ("external_link", "internal_link"),
     ("link_context", "link_size"),
     ("link_outline", "link_block"),
     "link_stretched",
@@ -34,27 +37,53 @@ UILINK_FIELDSET = [
             )
         },
     ),
-    (
-        _("Link settings"),
-        {
-            "classes": ("collapse",),
-            "fields": (
-                ("mailto", "phone"),
-                ("anchor", "target"),
-                ("file_link",),
-            ),
-        },
-    ),
 ]
+if not apps.is_installed("djangocms_url_manager"):
+    UILINK_FIELDSET += [
+        (
+            _("Link settings"),
+            {
+                "classes": ("collapse",),
+                "fields": (
+                    ("mailto", "phone"),
+                    ("anchor", "target"),
+                    ("file_link",),
+                ),
+            },
+        ),
+    ]
 
 
 class LinkPluginMixin:
+    link_fieldset_position = None
+    link_fields = (
+        (("site", "url_grouper"),)
+        if apps.is_installed("djangocms_url_manager")
+        else (
+            ("external_link", "internal_link"),
+            ("mailto", "phone"),
+            ("anchor", "target"),
+            "file_link",
+        )
+    )
+
     def get_form(self, request, obj=None, change=False, **kwargs):
         """The link form needs the request object to check permissions"""
         form = super().get_form(request, obj, change, **kwargs)
         form.request = request
         return form
 
+    def get_fieldsets(self, request, obj=None):
+        fieldsets = super().get_fieldsets(request, obj)
+        if self.link_fieldset_position is not None:
+            fieldsets = insert_fields(
+                fieldsets,
+                self.link_fields,
+                blockname=_("Link settings"),
+                position=self.link_fieldset_position,
+            )
+        return fieldsets
+
 
 @plugin_pool.register_plugin
 class LinkPlugin(
