@@ -15,7 +15,7 @@ class AlertPluginTestCase(TestFixture, CMSTestCase):
             language=self.language,
         )
         plugin.initialize_from_form(AlertForm).save()
-        self.page.publish(self.language)
+        self.publish(self.page, self.language)
 
         with self.login_user_context(self.superuser):
             response = self.client.get(self.request_url)
